#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.hybrid_shape_circle import HybridShapeCircle
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.length import Length


class HybridShapeCircleCenterAxis(HybridShapeCircle):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         CATGSMIDLItf.HybridShapeCircle
                |                             HybridShapeCircleCenterAxis
                | 
                | Represents the hybrid shape circle object defined using a point and
                | axis/line.
                | Role: To access the data of the hybrid shape circle center axis
                | object.
                | 
                | This data includes:
                | 
                |     Point
                |     Axis/Line
                |     Value of radius/diameter
                |     Diameter Mode
                |     Projection Mode
                | 
                | Use the CATIAHybridShapeFactory to create a HybridShapeCircleCenterAxis
                | object.
                | 
                | See also:
                |     HybridShapeFactory.AddNewCircleCenterAxis
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_circle_center_axis = com_object

    @property
    def axis(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Axis() As Reference
                | 
                |     Returns or sets the Axis of the circle.
                | 
                |     Example:
                |         This example retrieves in CircleAxis the Axis of plane in which circle
                |         is lying from HybShpCircle hybrid shape circle center axis
                |         feature
                | 
                |          Dim CircleAxis As Reference 
                |          Set CircleAxis = HybShpCircle.Axis

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_circle_center_axis.Axis)

    @axis.setter
    def axis(self, reference_axis: Reference):
        """
        :param Reference reference_axis:
        """

        self.hybrid_shape_circle_center_axis.Axis = reference_axis.com_object

    @property
    def diameter(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Diameter() As Length (Read Only)
                | 
                |     Returns the circle diameter. It is expressed as a Length literal. Succeeds
                |     only if DiameterMode is set to True. 
                | 
                | Example:
                |     This example retrieves in HybShpCircleDiameter the diameter of the
                |     HybShpCircle hybrid shape circle center axis feature
                | 
                |      Dim HybShpCircleDiameter As Length
                |      HybShpCircleDiameter = HybShpCircle.Diameter

        :return: Length
        :rtype: Length
        """

        return Length(self.hybrid_shape_circle_center_axis.Diameter)

    @property
    def diameter_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property DiameterMode() As boolean
                | 
                |     Returns or sets the DiameterMode.
                |     Legal values: True implies diameter False implies radius (default). When
                |     DiameterMode is changed, Radius/Diameter value, which is stored will not be
                |     modified.
                | 
                |     Example:
                | 
                |            This example sets that the DiameterMode of
                |           the HybShpCircle hybrid shape circle center axis
                |           feature
                |           
                | 
                |           HybShpCircle.DiameterMode = True

        :return: bool
        :rtype: bool
        """

        return self.hybrid_shape_circle_center_axis.DiameterMode

    @diameter_mode.setter
    def diameter_mode(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_circle_center_axis.DiameterMode = value

    @property
    def point(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Point() As Reference
                | 
                |     Returns or sets the Point of the circle.
                | 
                |     Example:
                |         This example retrieves in CirclePoint the point used for center
                |         computation from HybShpCircle hybrid shape circle center axis
                |         feature
                | 
                |          Dim CirclePoint As Reference 
                |          Set CirclePoint = HybShpCircle.Point

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_circle_center_axis.Point)

    @point.setter
    def point(self, reference_point: Reference):
        """
        :param Reference reference_point:
        """

        self.hybrid_shape_circle_center_axis.Point = reference_point.com_object

    @property
    def projection_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ProjectionMode() As boolean
                | 
                |     Returns or sets the ProjectionMode.
                |     Legal values: True (default) implies point will be projected on to
                |     axis/line False implies that point will be center of the
                |     circle.
                | 
                |     Example:
                | 
                |            This example sets that the ProjectionMode of
                |           the HybShpCircle hybrid shape circle center axis
                |           feature
                |           
                | 
                |           HybShpCircle.ProjectionMode = True

        :return: bool
        :rtype: bool
        """

        return self.hybrid_shape_circle_center_axis.ProjectionMode

    @projection_mode.setter
    def projection_mode(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_circle_center_axis.ProjectionMode = value

    @property
    def radius(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Radius() As Length (Read Only)
                | 
                |     Returns the circle radius. It is expressed as a Length literal. Succeeds
                |     only if DiameterMode is set to False. 
                | 
                | Example:
                |     This example retrieves in HybShpCircleRadius the radius of the HybShpCircle
                |     hybrid shape circle center axis feature
                | 
                |      Dim HybShpCircleRadius As Length
                |      HybShpCircleRadius = HybShpCircle.Radius

        :return: Length
        :rtype: Length
        """

        return Length(self.hybrid_shape_circle_center_axis.Radius)

    def __repr__(self):
        return f'HybridShapeCircleCenterAxis(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator

from pycatia.in_interfaces.reference import Reference
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class References(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     References
                | 
                | A collection of all the references aggregated in an object.
                | 
                | See also:
                |     Reference
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Reference)
        self.references = com_object

    def item(self, i_index: cat_variant) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Item(CATVariant iIndex) As Reference
                | 
                |     Returns a reference using its index or its name from the References
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the reference to retrieve from the
                |             collection of references. As a numerics, this index is the rank of the
                |             reference in the collection. The index of the first reference in the collection
                |             is 1, and the index of the last reference is Count. As a string, it is the name
                |             you assigned to the reference using the 
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved reference 
                |     Example:
                |         This example retrieves the last item in the RefList reference
                |         collection by means of the Count property.
                | 
                |          Dim LastRef As Reference
                |          Set LastRef = RefList.Item(RefList.Count)

        :param cat_variant i_index:
        :return: Reference
        :rtype: Reference
        """
        return Reference(self.references.Item(i_index))

    def __getitem__(self, n: int) -> Reference:
        if (n + 1) > self.count:
            raise StopIteration

        return Reference(self.references.item(n + 1))

    def __iter__(self) -> Iterator[Reference]:
        for i in range(self.count):
            yield self.child_object(self.com_object.item(i + 1))

    def __repr__(self):
        return f'References(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.sketcher_interfaces.curve_2D import Curve2D
from pycatia.system_interfaces.system_service import SystemService


class Parabola2D(Curve2D):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SketcherInterfaces.GeometricElement
                |                         SketcherInterfaces.Geometry2D
                |                             SketcherInterfaces.Curve2D
                |                                 Parabola2D
                | 
                | Class defining an parabola in 2D Space.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.parabola_2d = com_object

    @property
    def focal_distance(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FocalDistance() As double (Read Only)
                | 
                |     Returns the focal distance of the parabola in 2D space
                | 
                |     Parameters:
                | 
                |         oFocal
                |             The focal distance of the parabola

        :return: float
        :rtype: float
        """

        return self.parabola_2d.FocalDistance

    def get_axis(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetAxis(CATSafeArrayVariant oAxis)
                | 
                |     Returns the axis vector direction of the parabola in 2D
                |     space
                | 
                |     Parameters:
                | 
                |         oAxis[0]
                |             The X coordinate of the axis vector direction 
                |         oAxis[1]
                |             The Y coordinate of the axis vector direction

        :return: tuple
        :rtype: tuple
        """

        vba_function_name = 'get_axis'
        vba_code = """
        Public Function get_axis(parabola2_d)
            Dim oAxis (1)
            parabola2_d.GetAxis oAxis
            get_axis = oAxis
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_center(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetCenter(CATSafeArrayVariant oCenter)
                | 
                |     Returns the center of the parabola in 2D space
                | 
                |     Parameters:
                | 
                |         oCenter[0]
                |             The X Coordinate of the center point of the parabola
                |             
                |         oCenter[1]
                |             The Y Coordinate of the center point of the
                |             parabola

        :return: tuple
        :rtype: tuple
        """

        vba_function_name = 'get_center'
        vba_code = """
        Public Function get_center(parabola2_d)
            Dim oCenter(1)
            parabola2_d.GetCenter oCenter
            get_center = oCenter
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_data(self, i_center_x: float, i_center_y: float, i_axis_x: float, i_axis_y: float,
                 i_focal_distance: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetData(double iCenterX,
                | double iCenterY,
                | double iAxisX,
                | double iAxisY,
                | double iFocalDistance)
                | 
                |     Modifies the caracteristics of the parabola
                | 
                |     Parameters:
                | 
                |         iCenterX
                |             The X Coordinate of the parabola center 
                |         iCenterY
                |             The Y Coordinate of the parabola center 
                |         iAxisX
                |             The X coordinate of the axis vector direction 
                |         iAxisY
                |             The Y coordinate of the axis vector direction 
                |         iFocalDistance
                |             The focal distance of the parabola

        :param float i_center_x:
        :param float i_center_y:
        :param float i_axis_x:
        :param float i_axis_y:
        :param float i_focal_distance:
        :return: None
        :rtype: None
        """
        return self.parabola_2d.SetData(i_center_x, i_center_y, i_axis_x, i_axis_y, i_focal_distance)

    def __repr__(self):
        return f'Parabola2D(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject
from pycatia.types.general import cat_variant


class Hyperlink(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Hyperlink
                | 
                | Represents a hyperlink marker.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hyperlink = com_object

    def add_url(self, i_url: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddUrl(CATBSTR iUrl)
                | 
                |     Adds a url to an Hyperlink.
                | 
                |     Parameters:
                | 
                |         iUrl
                |             The URL to be added to the Hyperlink. 
                | 
                |     Example:
                | 
                |              This example links TheUrl to the NewHyperlink
                |              Hyperlink.
                |             
                | 
                |             NewHyperlink.AddUrl(TheUrl)

        :param str i_url:
        :return: None
        :rtype: None
        """
        return self.hyperlink.AddUrl(i_url)

    def count_object(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func CountObject() As long
                | 
                |     Returns the number of Url which are linked to the
                |     Hyperlink.
                | 
                |     Example:
                | 
                |              This example reads the number of Url in the Hyperlink NewHyperlink
                |              .
                |             
                | 
                |             Dim number As Integer
                |             number = NewHyperlink.CountObject

        :return: int
        :rtype: int
        """
        return self.hyperlink.CountObject()

    def item_object(self, i_index: cat_variant) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func ItemObject(CATVariant iIndex) As CATBSTR
                | 
                |     Returns an Url which is linked to the Hyperlink using its
                |     index.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the Url in the Hyperlink. The index of the first
                |             object is 1, and the index of the last object is CountObject.
                |             
                | 
                |     Returns:
                |         The retrieved Url 
                |     Example:
                | 
                |              This example retrieves in ThisUrl the ninth
                |              object
                |             from the NewHyperlink  Hyperlink.
                |             
                | 
                |             Dim ThisUrl As String
                |             Set ThisUrl = NewHyperlink.ItemObject(9)

        :param cat_variant i_index:
        :return: str
        :rtype: str
        """
        return self.hyperlink.ItemObject(i_index)

    def remove_object(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveObject(CATVariant iIndex)
                | 
                |     Removes an Url which is linked to the Hyperlink using its
                |     index.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the object in the Hyperlink. The index of the first
                |             object is 1, and the index of the last object is CountObject.
                |             
                | 
                |     Example:
                | 
                |              This example removes the ninth Url
                |             from the NewHyperlink  Hyperlink.
                |             
                | 
                |             NewHyperlink.RemoveObject(9)

        :param cat_variant i_index:
        :return: None
        :rtype: None
        """
        return self.hyperlink.RemoveObject(i_index)

    def __repr__(self):
        return f'Hyperlink(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.angle import Angle
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeRotate(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeRotate
                | 
                | Represents the hybrid shape rotate feature object.
                | Role: To access the data of the hybrid shape rotate feature object. This data
                | includes:
                | 
                |     The element to be rotated
                |     The rotation axis
                |     The angle and its value
                | 
                | LICENSING INFORMATION: Creation of volume result requires GSO
                | License
                | if GSO License is not granted , setting of Volume context has not
                | effect
                | Use the CATIAHybridShapeFactory to create HybridShapeFeature
                | object.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_rotate = com_object

    @property
    def angle(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Angle() As Angle (Read Only)
                | 
                |     Returns the rotation angle.

        :return: Angle
        :rtype: Angle
        """

        return Angle(self.hybrid_shape_rotate.Angle)

    @property
    def angle_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AngleValue() As double
                | 
                |     Returns or sets the rotation angle value.
                | 
                |     Example: This example retrieves in AngleValue the angle value for the
                |     Rotate hybrid shape feature.
                | 
                |      Dim AngleValue As double
                |      Set AngleValue = Rotate.AngleValue

        :return: float
        :rtype: float
        """

        return self.hybrid_shape_rotate.AngleValue

    @angle_value.setter
    def angle_value(self, value: float):
        """
        :param float value:
        """

        self.hybrid_shape_rotate.AngleValue = value

    @property
    def axis(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Axis() As Reference
                | 
                |     Returns or sets the rotation axis.
                |     Sub-element(s) supported (see Boundary object): Edge.
                | 
                |     Example: This example retrieves in RotationAxis the rotation axis for the
                |     Rotate hybrid shape feature.
                | 
                |      Dim RotationAxis As Reference
                |      Set RotationAxis = Rotate.Axis

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_rotate.Axis)

    @axis.setter
    def axis(self, reference_axis: Reference):
        """
        :param Reference reference_axis:
        """

        self.hybrid_shape_rotate.Axis = reference_axis.com_object

    @property
    def elem_to_rotate(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ElemToRotate() As Reference
                | 
                |     Returns or sets the element to be rotated.
                | 
                |     Example: This example retrieves in Elem the element to be rotated for the
                |     Rotate hybrid shape feature.
                | 
                |      Dim Elem As Reference
                |      Set Elem = Rotate.ElemToRotate

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_rotate.ElemToRotate)

    @elem_to_rotate.setter
    def elem_to_rotate(self, reference_element: Reference):
        """
        :param Reference reference_element:
        """

        self.hybrid_shape_rotate.ElemToRotate = reference_element.com_object

    @property
    def first_element(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstElement() As Reference
                | 
                |     Returns or sets the first element defining the rotation angle.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_rotate.FirstElement)

    @first_element.setter
    def first_element(self, reference_element: Reference):
        """
        :param Reference reference_element:
        """

        self.hybrid_shape_rotate.FirstElement = reference_element.com_object

    @property
    def first_point(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstPoint() As Reference
                | 
                |     Returns or sets the first point defining the rotation.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_rotate.FirstPoint)

    @first_point.setter
    def first_point(self, reference_point: Reference):
        """
        :param Reference reference_point:
        """

        self.hybrid_shape_rotate.FirstPoint = reference_point.com_object

    @property
    def orientation_of_first_element(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property OrientationOfFirstElement() As boolean
                | 
                |     Returns or sets the orientation of the first element defining the rotation
                |     angle.
                |     This applies in case of line or plane element.

        :return: bool
        :rtype: bool
        """

        return self.hybrid_shape_rotate.OrientationOfFirstElement

    @orientation_of_first_element.setter
    def orientation_of_first_element(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_rotate.OrientationOfFirstElement = value

    @property
    def orientation_of_second_element(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property OrientationOfSecondElement() As boolean
                | 
                |     Returns or sets the orientation of the second element defining the rotation
                |     angle.
                |     This applies in case of line or plane element.

        :return: bool
        :rtype: bool
        """

        return self.hybrid_shape_rotate.OrientationOfSecondElement

    @orientation_of_second_element.setter
    def orientation_of_second_element(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_rotate.OrientationOfSecondElement = value

    @property
    def rotation_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property RotationType() As long
                | 
                |     Returns or sets the type of the rotation definition.
                | 
                |         0= Axis + angle
                |         1= Axis + two elements
                |         2= Three Points
                |         3= Unknown type

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_rotate.RotationType

    @rotation_type.setter
    def rotation_type(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_rotate.RotationType = value

    @property
    def second_element(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondElement() As Reference
                | 
                |     Returns or sets the second element defining the rotation angle.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_rotate.SecondElement)

    @second_element.setter
    def second_element(self, reference_element: Reference):
        """
        :param Reference reference_element:
        """

        self.hybrid_shape_rotate.SecondElement = reference_element.com_object

    @property
    def second_point(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondPoint() As Reference
                | 
                |     Returns or sets the second point defining the rotation.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_rotate.SecondPoint)

    @second_point.setter
    def second_point(self, reference_point: Reference):
        """
        :param Reference reference_point:
        """

        self.hybrid_shape_rotate.SecondPoint = reference_point.com_object

    @property
    def third_point(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ThirdPoint() As Reference
                | 
                |     Returns or sets the third point defining the rotation.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_rotate.ThirdPoint)

    @third_point.setter
    def third_point(self, reference_point: Reference):
        """
        :param Reference reference_point:
        """

        self.hybrid_shape_rotate.ThirdPoint = reference_point.com_object

    @property
    def volume_result(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property VolumeResult() As boolean
                | 
                |     Returns or sets the volume result.
                |     Legal values: True if the result of Rotate is required as volume (option is
                |     effective only in case of volumes,requires GSO License) and False if it is
                |     needed as surface .
                | 
                |     Example:
                | 
                |           This example sets that the result of
                |          the hybShpRotate hybrid shape rotate is volume.
                |          
                | 
                |          hybShpRotate.VolumeResult = True

        :return: bool
        :rtype: bool
        """

        return self.hybrid_shape_rotate.VolumeResult

    @volume_result.setter
    def volume_result(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_rotate.VolumeResult = value

    def get_creation_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetCreationMode() As long
                | 
                |     Gets the creation mode.
                |     Legal values:
                | 
                |     0
                |         CATGSMTransfoModeUnset. Default behavior: creation mode by default for
                |         all features, modification mode for axis system
                |     1
                |         CATGSMTransfoModeCreation. Creation mode. 
                |     2
                |         CATGSMTransfoModeModification. Modification mode. 
                | 
                | Example:
                |     This example retrieves in oCreation the creation mode for the hybShpRotate
                |     hybrid shape feature.
                | 
                |      oCreation = hybShpRotate.GetCreationMode

        :return: int
        :rtype: int
        """
        return self.hybrid_shape_rotate.GetCreationMode()

    def set_creation_mode(self, i_creation: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetCreationMode(boolean iCreation)
                | 
                |     Sets the creation mode(creation or modification).
                |     Legal values: True if the result is a creation feature and False if the
                |     result is a modification feature.
                | 
                |     Example:
                | 
                |           This example sets that the mode of
                |          the hybShpRotate hybrid shape rotate to creation
                |          
                | 
                |          hybShpRotate.SetCreationMode True

        :param bool i_creation:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_rotate.SetCreationMode(i_creation)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_creation_mode'
        # # vba_code = """
        # # Public Function set_creation_mode(hybrid_shape_rotate)
        # #     Dim iCreation (2)
        # #     hybrid_shape_rotate.SetCreationMode iCreation
        # #     set_creation_mode = iCreation
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'HybridShapeRotate(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.angle import Angle
from pycatia.knowledge_interfaces.length import Length
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeSphere(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeSphere
                | 
                | Represents the hybrid shape sphere feature object.
                | Role: To access the data of the hybrid shape sphere explicit feature
                | object.
                | The Sphere feature : a Sphere is made up of 4 angles parameters.
                | 
                | See also:
                |     HybridShapeFactory

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_sphere = com_object

    @property
    def axis(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Axis() As Reference
                | 
                |     Returns or sets axis on the object.
                | 
                |     Parameters:
                | 
                |         oDir
                |             return value for CATScript applications, with (IDLRETVAL) function
                |             type 
                | 
                |     See also:
                |         Reference 
                |     See also:
                |         HybridShapeFactory

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_sphere.Axis)

    @axis.setter
    def axis(self, reference_axis: Reference):
        """
        :param Reference reference_axis:
        """

        self.hybrid_shape_sphere.Axis = reference_axis.com_object

    @property
    def begin_meridian_angle(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property BeginMeridianAngle() As Angle (Read Only)
                | 
                |     Returns BeginMeridianAngle on the object.
                | 
                |     Parameters:
                | 
                |         oAngle
                |             return value for CATScript applications, with (IDLRETVAL) function
                |             type 
                | 
                |     See also:
                |         Angle 
                |     See also:
                |         HybridShapeFactory

        :return: Angle
        :rtype: Angle
        """

        return Angle(self.hybrid_shape_sphere.BeginMeridianAngle)

    @property
    def begin_parallel_angle(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property BeginParallelAngle() As Angle (Read Only)
                | 
                |     Returns BeginParallelAngle on the object.
                | 
                |     Parameters:
                | 
                |         oAngle
                |             return value for CATScript applications, with (IDLRETVAL) function
                |             type 
                | 
                |     See also:
                |         Angle 
                |     See also:
                |         HybridShapeFactory

        :return: Angle
        :rtype: Angle
        """

        return Angle(self.hybrid_shape_sphere.BeginParallelAngle)

    @property
    def center(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Center() As Reference
                | 
                |     Returns or sets the sphere center.
                |     Sub-element(s) supported (see Boundary object): Vertex.
                | 
                |     Example:
                |         This example retrieves in HybShpSphereCenter the center of the
                |         HybShpSphere hybrid shape sphere.
                | 
                |          Dim HybShpSphereCenter As Reference
                |          HybShpSphereCenter = HybShpSphere.Center

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_sphere.Center)

    @center.setter
    def center(self, reference: Reference):
        """
        :param Reference reference:
        """

        self.hybrid_shape_sphere.Center = reference.com_object

    @property
    def end_meridian_angle(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property EndMeridianAngle() As Angle (Read Only)
                | 
                |     Returns EndMeridianAngle on the object.
                | 
                |     Parameters:
                | 
                |         oAngle
                |             return value for CATScript applications, with (IDLRETVAL) function
                |             type 
                | 
                |     See also:
                |         Angle 
                |     See also:
                |         HybridShapeFactory

        :return: Angle
        :rtype: Angle
        """

        return Angle(self.hybrid_shape_sphere.EndMeridianAngle)

    @property
    def end_parallel_angle(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property EndParallelAngle() As Angle (Read Only)
                | 
                |     Returns EndParallelAngle on the object.
                | 
                |     Parameters:
                | 
                |         oAngle
                |             return value for CATScript applications, with (IDLRETVAL) function
                |             type 
                | 
                |     See also:
                |         Angle 
                |     See also:
                |         HybridShapeFactory

        :return: Angle
        :rtype: Angle
        """

        return Angle(self.hybrid_shape_sphere.EndParallelAngle)

    @property
    def limitation(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Limitation(long iLimitationType)
                | 
                |     Returns whether the sphere is created as a whole sphere or
                |     not.
                |     Legal values: 0 for a sphere with angles and 1 for a whole
                |     sphere.
                | 
                |     Example:

        :return: False
        :rtype: False
        """

        return self.hybrid_shape_sphere.Limitation

    @limitation.setter
    def limitation(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_sphere.Limitation = value

    @property
    def radius(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Radius() As Length (Read Only)
                | 
                |     Role: Get sphere radius.
                | 
                |     Parameters:
                | 
                |         oRadius
                |             Sphere radius return value for CATScript applications, with
                |             (IDLRETVAL) function type 
                | 
                |     See also:
                |         Length 
                |     See also:
                |         HybridShapeFactory

        :return: Length
        :rtype: Length
        """

        return Length(self.hybrid_shape_sphere.Radius)

    def set_begin_meridian_angle(self, i_angle: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetBeginMeridianAngle(double iAngle)
                | 
                |     Sets BeginMeridianAngle on the object.
                | 
                |     Parameters:
                | 
                |         iAngle
                | 
                |     See also:
                |         Angle 
                |     See also:
                |         HybridShapeFactory

        :param float i_angle:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_sphere.SetBeginMeridianAngle(i_angle)

    def set_begin_parallel_angle(self, i_angle: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetBeginParallelAngle(double iAngle)
                | 
                |     Sets BeginParallelAngle on the object.
                | 
                |     Parameters:
                | 
                |         iAngle
                | 
                |     See also:
                |         Angle 
                |     See also:
                |         HybridShapeFactory

        :param float i_angle:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_sphere.SetBeginParallelAngle(i_angle)

    def set_end_meridian_angle(self, i_angle: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetEndMeridianAngle(double iAngle)
                | 
                |     Sets EndMeridianAngle on the object.
                | 
                |     Parameters:
                | 
                |         iAngle
                | 
                |     See also:
                |         Angle 
                |     See also:
                |         HybridShapeFactory

        :param float i_angle:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_sphere.SetEndMeridianAngle(i_angle)

    def set_end_parallel_angle(self, i_angle: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetEndParallelAngle(double iAngle)
                | 
                |     Sets EndParallelAngle on the object.
                | 
                |     Parameters:
                | 
                |         iAngle
                | 
                |     See also:
                |         Angle 
                |     See also:
                |         HybridShapeFactory

        :param float i_angle:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_sphere.SetEndParallelAngle(i_angle)

    def set_radius(self, i_radius: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetRadius(double iRadius)
                | 
                |     Sets Radius on the object.
                | 
                |     Parameters:
                | 
                |         iAngle
                | 
                |     See also:
                |         Angle 
                |     See also:
                |         HybridShapeFactory

        :param float i_radius:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_sphere.SetRadius(i_radius)

    def __repr__(self):
        return f'HybridShapeSphere(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.move import Move
from pycatia.mec_mod_interfaces.shape import Shape
from pycatia.system_interfaces.any_object import AnyObject


class Solid(Shape):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         Solid
                | 
                | Represents an imported solid object.
                | Role: the imported solid is a solid obtained from copy/paste with link or
                | design in context.
                | The solid object has a link to a source element obtained from SourceElement and
                | a source product obtained from SourceProduct .
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.solid = com_object

    @property
    def move(self) -> Move:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Move() As Move (Read Only)
                | 
                |     Returns the move object of the solid.
                |     Role: The move object is aggregated by the solid object and itself
                |     aggregates a movable object to which you can apply a move transformation by
                |     means of an isometry matrix. It moves the solid according to this
                |     isometry.
                | 
                |     Example:
                | 
                |           This example retrieves the move object EngineMoveObject for
                |           the
                |          Engine product.
                |          
                | 
                |          Dim EngineMoveObject As Move
                |          Set EngineMoveObject = Engine.Move
                |          
                | 
                | 
                |          
                | 
                |     See also:
                |         Move

        :return: Move
        :rtype: Move
        """

        return Move(self.solid.Move)

    @property
    def source_element(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SourceElement() As AnyObject (Read Only)
                | 
                |     Returns the source element of the imported solid.
                |     Role: returns the linked element in the source part.
                | 
                |     Example:
                |         The following example returns in element the source element of the
                |         imported solid importedSolid:
                | 
                |          Set element = importedSolid.SourceElement

        :return: AnyObject
        :rtype: AnyObject
        """

        return AnyObject(self.solid.SourceElement)

    @property
    def source_product(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SourceProduct() As AnyObject (Read Only)
                | 
                |     Returns the source product instance of the imported solid.
                |     Role: returns the product instance which was selected when the import was
                |     created.
                | 
                |     Example:
                |         The following example returns in prod1 the source product instance of
                |         the imported solid importedSolid:
                | 
                |          Set prod1 = importedSolid.SourceProduct

        :return: AnyObject
        :rtype: AnyObject
        """

        return AnyObject(self.solid.SourceProduct)

    def __repr__(self):
        return f'Solid(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from typing import TYPE_CHECKING

from pycatia.drafting_interfaces.drawing_sheets import DrawingSheets
from pycatia.in_interfaces.document import Document
from pycatia.knowledge_interfaces.parameters import Parameters
from pycatia.knowledge_interfaces.relations import Relations

if TYPE_CHECKING:
    from pycatia.drafting_interfaces.drawing_root import DrawingRoot


class DrawingDocument(Document):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.Document
                |                         DrawingDocument
                | 
                | Represents the Document object for drawings.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.drawing_document = com_object

    @property
    def drawing_root(self) -> 'DrawingRoot':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property DrawingRoot() As DrawingRoot (Read Only)
                | 
                |     Retrieves the drawing root in the drawing document.
                | 
                |     Example:
                |         This example retrieves the drawing from the active document, supposed
                |         to be a drawing document.
                | 
                |          CATIA.ActiveDocument.DrawingRoot

        :return: DrawingRoot
        :rtype: DrawingRoot
        """
        from pycatia.drafting_interfaces.drawing_root import DrawingRoot
        return DrawingRoot(self.drawing_document.DrawingRoot)

    @property
    def parameters(self) -> Parameters:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Parameters() As Parameters (Read Only)
                | 
                |     Returns the collection of parameters of the drawing
                |     document.
                | 
                |     Example:
                | 
                |           This example retrieves in DrawingParameters the collection
                |           of
                |          parameters currently managed by the active document, supposed to be
                |          a
                |          drawing document.
                |          
                | 
                |          Dim DrawingParameters As Parameters
                |          Set DrawingParameters = CATIA.ActiveDocument.Parameters

        :return: Parameters
        :rtype: Parameters
        """

        return Parameters(self.drawing_document.Parameters)

    @property
    def relations(self) -> Relations:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Relations() As Relations (Read Only)
                | 
                |     Returns the collection of relations of the drawing
                |     document.
                | 
                |     Example:
                | 
                |           This example retrieves in DrawingRelations the collection
                |           of
                |          relations currently managed by the active document, supposed to be
                |          a
                |          drawing document.
                |          
                | 
                |          Dim DrawingRelations As Relations
                |          Set DrawingRelations = CATIA.ActiveDocument.Relations

        :return: Relations
        :rtype: Relations
        """

        return Relations(self.drawing_document.Relations)

    @property
    def sheets(self) -> DrawingSheets:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Sheets() As DrawingSheets (Read Only)
                | 
                |     Returns the collection of drawing sheets of the drawing
                |     document.
                | 
                |     Example:
                |         This example retrieves in SheetCollection the collection of sheets
                |         currently managed by the active document, supposed to be a drawing
                |         document.
                | 
                |          Dim SheetCollection As DrawingSheets
                |          Set SheetCollection = CATIA.ActiveDocument.Sheets

        :return: DrawingSheets
        :rtype: DrawingSheets
        """

        return DrawingSheets(self.drawing_document.Sheets)

    @property
    def standard(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Standard() As CatDrawingStandard
                | 
                |     Returns or sets the drawing standard of the drawing
                |     document.
                | 
                |     Example:
                |         This example sets the drawing standard of the active document, supposed
                |         to be a drawing document, to ISO.
                | 
                |          CATIA.ActiveDocument.Standard = catISO

        :return: int
        :rtype: int
        """

        return self.drawing_document.Standard

    @standard.setter
    def standard(self, value: int):
        """
        :param int value:
        """

        self.drawing_document.Standard = value

    def isolate(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Isolate()
                | 
                |     Isolates all the drawing views of all the drawing sheets of the drawing
                |     document.
                | 
                |     Example:
                |         This example isolates all the drawing views of all the drawing sheets
                |         of the active document, supposed to be a drawing
                |         document.
                | 
                |          CATIA.ActiveDocument.Isolate

        :return: None
        :rtype: None
        """
        return self.drawing_document.Isolate()

    def update(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Update()
                | 
                |     Updates all the drawing sheets of the drawing document.
                | 
                |     Example:
                |         This example updates the active document, supposed to be a drawing
                |         document.
                | 
                |          CATIA.ActiveDocument.Update

        :return: None
        :rtype: None
        """
        return self.drawing_document.Update()

    def __repr__(self):
        return f'DrawingDocument(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.types.general import cat_variant


class FixTogether(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     FixTogether
                | 
                | The object that manages a sequence of products or
                | fixTogethers.
                | 
                | It belongs to the FixTogether collection of a Product.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.fix_together = com_object

    @property
    def fix_togethers_count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FixTogethersCount() As long (Read Only)
                | 
                |     Returns the number of FixTogether entities in the
                |     FixTogether.
                | 
                |     Example:
                |         The following example retrieves in fixTogethersCount the number of
                |         FixTogethers of the myFixTogether FixTogether :
                | 
                |          fixTogethersCount = myFixTogether.FixTogethersCount

        :return: int
        :rtype: int
        """

        return self.fix_together.FixTogethersCount

    @property
    def products_count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ProductsCount() As long (Read Only)
                | 
                |     Returns the number of products fixed together in the
                |     FixTogether.
                | 
                |     Example:
                |         The following example retrieves in productsCount the number of products
                |         of the myFixTogether FixTogether :
                | 
                |          productsCount = myFixTogether.ProductsCount

        :return: int
        :rtype: int
        """

        return self.fix_together.ProductsCount

    def add_fix_together(self, i_fix_together: 'FixTogether') -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddFixTogether(FixTogether iFixTogether)
                | 
                |     Add a fixTogether to a FixTogether. The fixTogether is fixed together with
                |     the products or fixTogethers already contained in the FixTogether.
                |     
                | Example:
                |     The following example adds a FixTogether fixTogether in a FixTogether
                |     myFixTogether.
                | 
                |      myFixTogether.AddFixTogether(fixTogether)

        :param FixTogether i_fix_together:
        :return: None
        :rtype: None
        """
        return self.fix_together.AddFixTogether(i_fix_together.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_fix_together'
        # # vba_code = """
        # # Public Function add_fix_together(fix_together)
        # #     Dim iFixTogether (2)
        # #     fix_together.AddFixTogether iFixTogether
        # #     add_fix_together = iFixTogether
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_product(self, i_product: Product) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddProduct(Product iProduct)
                | 
                |     Add a product to a FixTogether. The product is fixed together with the
                |     products and fixTogethers already contained in the FixTogether.
                |     
                | Example:
                |     The following example adds a Product myProduct in a
                |     FixTogether.
                | 
                |      myFixTogether.AddProduct(myProduct)

        :param Product i_product:
        :return: None
        :rtype: None
        """
        return self.fix_together.AddProduct(i_product.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_product'
        # # vba_code = """
        # # Public Function add_product(fix_together)
        # #     Dim iProduct (2)
        # #     fix_together.AddProduct iProduct
        # #     add_product = iProduct
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_fix_together(self, i_index: cat_variant) -> 'FixTogether':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetFixTogether(CATVariant iIndex) As FixTogether
                | 
                |     Returns a FixTogether using its index or its name in the
                |     FixTogether.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the FixTogether to retrieve. As a
                |             numerics, this index is the rank of the FixTogether in the FixTogethers of the
                |             FixTogether. The index of the first FixTogether is 1, and the index of the last
                |             FixTogether is FixTogether sCount. As a string, it is the name you assigned to
                |             the FixTogether using the 
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved FixTogether 
                |     Example:
                |         This example retrieves in thisFixTogether the fifth FixTogether and in
                |         thatFixTogether the FixTogether named myFixTogether in the FixTogethers of the
                |         FixTogether.
                | 
                |          Dim thisFixTogether As FixTogether
                |          Set thisFixTogether = myFixTogether.GetFixTogether(5)
                |          Dim thatFixTogether As FixTogether
                |          Set thatFixTogether = myFixTogether.GetFixTogether("myFixTogether")

        :param cat_variant i_index:
        :return: FixTogether
        :rtype: FixTogether
        """
        return FixTogether(self.fix_together.GetFixTogether(i_index))

    def get_product(self, i_index: cat_variant) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetProduct(CATVariant iIndex) As Product
                | 
                |     Returns a Product using its index or its name in the
                |     FixTogether.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Product to retrieve. As a numerics,
                |             this index is the rank of the Product in the products of the FixTogether. The
                |             index of the first Product is 1, and the index of the last Product is
                |             ProductsCount. As a string, it is the name you assigned to the Product using
                |             the 
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved Product 
                |     Example:
                |         This example retrieves in thisProduct the fifth Product and in
                |         thatProduct the Product named myProduct in the products of the
                |         FixTogether.
                | 
                |          Dim thisProduct As Product
                |          Set thisProduct = myFixTogether.GetProduct(5)
                |          Dim thatProduct As Product
                |          Set thatProduct = myFixTogether.GetProduct("myProduct")

        :param cat_variant i_index:
        :return: Product
        :rtype: Product
        """
        return Product(self.fix_together.GetProduct(i_index))

    def remove_fix_together(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveFixTogether(CATVariant iIndex)
                | 
                |     Removes a FixTogether from the FixTogether.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the FixTogether to remove from the
                |             FixTogether. As a numerics, this index is the rank of the FixTogether in the
                |             FixTogethers of the FixTogether. The index of the first FixTogether is 1, and
                |             the index of the last FixTogether is FixTogethersCount. As a string, it is the
                |             name you assigned to the FixTogether using the 
                | 
                |         AnyObject.Name property. 
                | 
                | Example:
                |     This example removes the last FixTogether of the
                |     FixTogether.
                | 
                |     fixTogether.RemoveFixTogether(fixTogether.FixTogethersCount)

        :param cat_variant i_index:
        :return: None
        :rtype: None
        """
        return self.fix_together.RemoveFixTogether(i_index)

    def remove_product(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveProduct(CATVariant iIndex)
                | 
                |     Removes a Product from the FixTogether.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Product to remove from the
                |             FixTogether. As a numerics, this index is the rank of the Product in the
                |             products of the FixTogether. The index of the first Product is 1, and the index
                |             of the last Product is ProductsCount. As a string, it is the name you assigned
                |             to the FixTogether using the 
                | 
                |         AnyObject.Name property. 
                | 
                | Example:
                |     This example removes the last Product of the FixTogether.
                | 
                |      fixTogether.RemoveProduct(fixTogether.ProductsCount)

        :param cat_variant i_index:
        :return: None
        :rtype: None
        """
        return self.fix_together.RemoveProduct(i_index)

    def __repr__(self):
        return f'FixTogether(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.relation import Relation


class Check(Relation):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     KnowledgeInterfaces.KnowledgeObject
                |                        KnowledgeInterfaces.KnowledgeActivateObject
                |                             KnowledgeInterfaces.Relation
                |                                 Check
                | 
                | Represents the check relation.
                | The following example shows how to create a check which checks if a given mass
                | is less than 10kg. The mass should be defined previously:
                | 
                | 	Dim CATDocs As Documents
                |  Set CATDocs = CATIA.Documents
                |  Dim part1 As Document
                |  Set part1   = CATDocs.Add("CATPart")
                |  Dim mass As RealParam
                |  Set mass         = part1.Part.Parameters.CreateReal("mass", 5.)
                |  Dim maximummass As Check
                |  Set maximummass = part1.Relations.CreateCheck
                |                     ("maximummass",
                |                      "Ensures that mass is less than 10 kg",
                |                      "mass<10kg")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.check = com_object

    @property
    def diagnosis(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Diagnosis() As boolean (Read Only)
                | 
                |     Returns the check diagnosis. True if the condition of the check is
                |     verified. False otherwise.

        :return: bool
        :rtype: bool
        """

        return self.check.Diagnosis

    @property
    def severity(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Severity() As long
                | 
                |     Returns or sets the check severity. The severity is the way the check will
                |     manifest itself:
                |     Silent (1)
                |     Information (2)
                |     Warning (3)

        :return: int
        :rtype: int
        """

        return self.check.Severity

    @severity.setter
    def severity(self, value: int):
        """
        :param int value:
        """

        self.check.Severity = value

    def __repr__(self):
        return f'Check(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.file_component import FileComponent
from pycatia.in_interfaces.text_stream import TextStream


class File(FileComponent):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.FileComponent
                |                         File
                | 
                | Represents the file object.
                | Role: The file object allows to manipulate files with UNIX and Windows. Use it
                | instead of the one of Visual Basic to make portable macros. Its gives access to
                | information about the file and can open a file as a TextStream
                | object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.file = com_object

    @property
    def size(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Size() As long (Read Only)
                | 
                |     Returns the size of the file.
                | 
                |     Example:
                |         This example retrieves in FileSize the size of the File
                |         TestFile.
                | 
                |          Dim FileSize As Long
                |          FileSize = TestFile.Size

        :return: int
        :rtype: int
        """

        return self.file.Size

    @property
    def type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Type() As CATBSTR (Read Only)
                | 
                |     Returns the type of the file. For instance, if the file has a .txt or .doc
                |     extension, its type will be "Text Document".
                | 
                |     Example:
                |         This example retrieves in FileType the type of the File
                |         TestFile.
                | 
                |          Dim FileType As String
                |          FileSize = TestFile.Size

        :return: str
        :rtype: str
        """

        return self.file.Type

    def open_as_text_stream(self, i_mode: str) -> TextStream:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func OpenAsTextStream(CATBSTR iMode) As TextStream
                | 
                |     Opens the file and retrieves it as a TextSteam object. Paramater iMode can
                |     have the value "ForReading", "ForWriting" or
                |     "ForAppending".
                | 
                |     Example:
                |         This example opens the file TestFile for reading and retrieves in the
                |         text stream TextStr.
                | 
                |          Dim TextStr As CATIATextSteam
                |          Set TextStr = TestFile.OpenAsTextStream("ForReading")

        :param str i_mode:
        :return: TextStream
        :rtype: TextStream
        """
        return TextStream(self.file.OpenAsTextStream(i_mode))

    def __repr__(self):
        return f'File(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.angle import Angle
from pycatia.part_interfaces.transformation_shape import TransformationShape
from pycatia.system_interfaces.any_object import AnyObject


class Pattern(TransformationShape):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         PartInterfaces.TransformationShape
                |                             Pattern
                | 
                | Represents the pattern shape.
                | It is the base object for rectangular and circular patterns. A pattern shape is
                | a set of copies of the same shape. The copy is done according to linear and
                | angular repartitions.
                | 
                | See also:
                |     CircPattern, RectPattern, Repartition, LinearRepartition,
                |     AngularRepartition
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.pattern = com_object

    @property
    def item_to_copy(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ItemToCopy() As AnyObject
                | 
                |     Returns or sets the shape to be copied.
                | 
                |     Example:
                |         The following example returns in shape the copied shape of the pattern
                |         firstPattern, and then sets it to pad1:
                | 
                |          Set shape = firstPattern.ItemToCopy
                |          firstPattern.ItemToCopy = pad1

        :return: AnyObject
        :rtype: AnyObject
        """

        return AnyObject(self.pattern.ItemToCopy)

    @item_to_copy.setter
    def item_to_copy(self, value: AnyObject):
        """
        :param AnyObject value:
        """

        self.pattern.ItemToCopy = value

    @property
    def rotation_angle(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property RotationAngle() As Angle (Read Only)
                | 
                |     Returns the pattern global rotation angle. The rotation is applied to the
                |     whole pattern, but not to the shapes themselves. The shape to be copied is used
                |     as the rotation center.
                | 
                |     Example:
                |         The following example returns in globAng the rotation of pattern
                |         firstPattern:
                | 
                |          Set globAng = firstPattern.RotationAngle

        :return: Angle
        :rtype: Angle
        """

        return Angle(self.pattern.RotationAngle)

    def activate_position(self, i_pos_u: int, i_pos_v: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub ActivatePosition(long iPosU,
                | long iPosV)
                | 
                |     Allows user to activate an instance of the pattern.
                | 
                |     Parameters:
                | 
                |         iPosU
                |             The position of the instance in the U direction 
                |         iPosV
                |             The position of the instance in the V direction

        :param int i_pos_u:
        :param int i_pos_v:
        :return: None
        :rtype: None
        """
        return self.pattern.ActivatePosition(i_pos_u, i_pos_v)

    def desactivate_position(self, i_pos_u: int, i_pos_v: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub DesactivatePosition(long iPosU,
                | long iPosV)
                | 
                |     Allows user to desactivate an instance of the pattern.
                | 
                |     Parameters:
                | 
                |         iPosU
                |             The position of the instance in the U direction 
                |         iPosV
                |             The position of the instance in the V direction

        :param int i_pos_u:
        :param int i_pos_v:
        :return: None
        :rtype: None
        """
        return self.pattern.DesactivatePosition(i_pos_u, i_pos_v)

    def __repr__(self):
        return f'Pattern(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.length import Length
from pycatia.part_interfaces.sketch_based_shape import SketchBasedShape


class Stiffener(SketchBasedShape):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         PartInterfaces.SketchBasedShape
                |                             Stiffener
                | 
                | Represents the stiffener shape.
                | A stiffener is made up of a sketch used as the stiffener profile, that is
                | extruded (offset) and that fills the nearest shape. This is a "positive" shape:
                | it adds material to the body it belongs to.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.stiffener = com_object

    @property
    def is_from_top(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property IsFromTop() As boolean
                | 
                |     Returns or sets whether the stiffener is From Side or From
                |     Top.
                |     True if the stiffener is From Top stiffener with respect to the base
                |     sketch. False if the stiffener is From Side stiffener with respect to the base
                |     sketch.
                | 
                |     Example:
                |         The following example returns in FromTopFlag whether the firstStiffener
                |         stiffener is From Top, and then sets it as From Top stiffener with respect to
                |         its base sketch:
                | 
                |          Set FromTopFlag = firstStiffener.IsFromTop
                |          firstStiffener.IsFromTop  = True

        :return: bool
        :rtype: bool
        """

        return self.stiffener.IsFromTop

    @is_from_top.setter
    def is_from_top(self, value: bool):
        """
        :param bool value:
        """

        self.stiffener.IsFromTop = value

    @property
    def is_symmetric(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property IsSymmetric() As boolean
                | 
                |     Returns or sets whether the stiffener is symmetric.
                |     True if the stiffener is symmetric with respect to the base
                |     sketch.
                | 
                |     Example:
                |         The following example returns in symFlag whether the firstStiffener
                |         stiffener is symmetric, and then sets it as symmetric with respect to its base
                |         sketch:
                | 
                |          Set symFlag = firstStiffener.IsSymmetric
                |          firstStiffener.IsSymmetric  = True

        :return: bool
        :rtype: bool
        """

        return self.stiffener.IsSymmetric

    @is_symmetric.setter
    def is_symmetric(self, value: bool):
        """
        :param bool value:
        """

        self.stiffener.IsSymmetric = value

    @property
    def thickness(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Thickness() As Length (Read Only)
                | 
                |     Returns the stiffener thickness. This is half of the thickness if the
                |     stiffener is symmetrical, and the thickness otherwise.
                | 
                |     Example:
                |         The following example returns in thickness the thickness of the
                |         firstStiffener stiffener:
                | 
                |          Set thickness = firstStiffener.Thickness

        :return: Length
        :rtype: Length
        """

        return Length(self.stiffener.Thickness)

    @property
    def thickness_from_top(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ThicknessFromTop() As Length (Read Only)
                | 
                |     Returns the stiffener thickness top in case of From Top stiffener. This is
                |     equal to first thickness if the stiffener is symmetrical,
                | 
                |     Example:
                |         The following example returns in thicknessfromtop the thickness of the
                |         firstStiffener stiffener:
                | 
                |          Set thicknessfromtop = firstStiffener.ThicknessFromTop

        :return: Length
        :rtype: Length
        """

        return Length(self.stiffener.ThicknessFromTop)

    def reverse_depth(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub ReverseDepth()
                | 
                |     Reverses the stiffener direction. This is useful for finding the shape to
                |     reach.
                | 
                |     Example:
                |         The following example reverses the current direction of the
                |         firstStiffener stiffener:
                | 
                |          firstStiffener.ReverseDepth

        :return: None
        :rtype: None
        """
        return self.stiffener.ReverseDepth()

    def reverse_thickness(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub ReverseThickness()
                | 
                |     Reverses the stiffener thickness direction. The stiffener thickness is
                |     swapped with respect to the base sketch.
                | 
                |     Example:
                |         The following example reverses the current direction of the
                |         firstStiffener stiffener:
                | 
                |          firstStiffener.ReverseThickness

        :return: None
        :rtype: None
        """
        return self.stiffener.ReverseThickness()

    def __repr__(self):
        return f'Stiffener(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.tps_interfaces.tps_view import TPSView
from pycatia.types.general import cat_variant


class TPSViewFactory(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     TPSViewFactory
                | 
                | Represents the TPS view factory object.
                | All the created views are added to the annotation set object from which this
                | interface is retrieved, thanks to the AnnotationSet.TPSFactory
                | property.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.tps_view_factory = com_object

    def create_view(self, i_plane: Reference, i_view_type: cat_variant) -> TPSView:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateView(Reference iPlane,
                | CATVariant iViewType) As TPSView
                | 
                |     Creates a view.
                | 
                |     Parameters:
                | 
                |         iPlane
                |             The plane onto which the view will be created 
                |         iViewType
                |             The view type
                |             Legal values:
                | 
                |                 1: Front View
                |                 2: Section View
                |                 3: Cut View

        :param Reference i_plane:
        :param CATVariant i_view_type:
        :return: TPSView
        :rtype: TPSView
        """
        return TPSView(self.tps_view_factory.CreateView(i_plane.com_object, i_view_type))

    def __repr__(self):
        return f'TpsViewFactory(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from typing import TYPE_CHECKING

from pycatia.navigator_interfaces.annotated_views import AnnotatedViews
from pycatia.navigator_interfaces.group import Group
from pycatia.navigator_interfaces.marker_3Ds import Marker3Ds
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.system_interfaces.system_service import SystemService

if TYPE_CHECKING:
    from pycatia.in_interfaces.document import Document

class Section(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Section
                | 
                | Represents the Section object.
                | The Section object is a specification of a sectioning display and
                | computationwith a section plane, section slice or section box.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.section = com_object

    @property
    def annotated_views(self) -> AnnotatedViews:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AnnotatedViews() As AnnotatedViews (Read Only)
                | 
                |     Returns the AnnotatedViews collection of the section.
                | 
                |     Example:
                | 
                |              This example retrieves the AnnotatedViews collection of NewSection
                |              Section.
                |             
                | 
                |             Dim TheAnnotatedViewsList As AnnotatedViews
                |             Set TheAnnotatedViewsList = NewSection.AnnotatedViews

        :return: AnnotatedViews
        :rtype: AnnotatedViews
        """

        return AnnotatedViews(self.section.AnnotatedViews)

    @property
    def behavior(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Behavior() As CatSectionBehavior
                | 
                |     Returns or sets the general behavior of the section: Freeze, Automatic
                |     update, manual update
                | 
                |     The behavior value are defined in CatSectionBehavior.
                | 
                |     Example:
                | 
                |              The first example retrieves the behavior of NewSection
                |              Section.
                |             
                | 
                |             Dim SectionBehavior As CatSectionBehavior
                |             Behavior = NewSection.Behavior
                |             
                | 
                | 
                |             
                | 
                |                 The second example sets the behavior of NewSection
                |                 Section.
                |                 
                | 
                |                 NewSection.Behavior = catSectionBehaviorAutomatic

        :return: int
        :rtype: int
        """

        return self.section.Behavior

    @behavior.setter
    def behavior(self, value: int):
        """
        :param int value:
        """

        self.section.Behavior = value

    @property
    def cut_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CutMode() As long
                | 
                |     Returns or sets the cutting mode of the section.
                | 
                |     The cutting mode value is 1 for clipping or 0 without
                |     clipping.
                | 
                |     Example:
                | 
                |              The first example retrieves the cutting mode of NewSection
                |              Section.
                |             
                | 
                |             Dim SectionMode As Integer
                |             SectionMode = NewSection.CutMode
                |             
                | 
                | 
                |             
                | 
                |                 The second example sets the cutting mode of NewSection
                |                 Section.
                |                 
                | 
                |                 NewSection.CutMode = 1

        :return: int
        :rtype: int
        """

        return self.section.CutMode

    @cut_mode.setter
    def cut_mode(self, value: int):
        """
        :param int value:
        """

        self.section.CutMode = value

    @property
    def group(self) -> Group:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Group() As Group
                | 
                |     Returns or sets the sectioned group.
                | 
                |     By default, it is the all leaves group.
                | 
                |     Example:
                | 
                |              The first example retrieves the group of NewSection
                |              Section.
                |
                |             Dim AGroup As Group
                |             AGroup = NewSection.Group
                |
                |                 The second example sets the group of NewSection
                |                 Section.
                |
                |                 Dim AGroup As Group
                |                 NewSection.Group = AGroup

        :return: Group
        :rtype: Group
        """

        return Group(self.section.Group)

    @group.setter
    def group(self, value: Group):
        """
        :param Group value:
        """

        self.section.Group = value

    @property
    def height(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Height() As double
                | 
                |     Returns or sets the height of the section.
                | 
                |     The height value must be greater than 0.
                | 
                |     Example:
                | 
                |              The first example retrieves the height of NewSection
                |              Section.
                |             
                | 
                |             Dim SectionHeight As double
                |             SectionHeight = NewSection.Height
                |             
                | 
                | 
                |             
                | 
                |                 The second example sets the height value of NewSection
                |                 Section.
                |                 
                | 
                |                 NewSection.Height = 100.

        :return: float
        :rtype: float
        """

        return self.section.Height

    @height.setter
    def height(self, value: float):
        """
        :param float value:
        """

        self.section.Height = value

    @property
    def marker_3ds(self) -> Marker3Ds:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Marker3Ds() As Marker3Ds (Read Only)
                | 
                |     Returns the Marker3Ds collection of the section.
                | 
                |     Example:
                | 
                |              This example retrieves the Marker3Ds collection of NewSection
                |              Section.
                |             
                | 
                |             Dim TheMarker3DsList As Marker3Ds
                |             Set TheMarker3DsList = NewSection.Marker3Ds

        :return: Marker3Ds
        :rtype: Marker3Ds
        """

        return Marker3Ds(self.section.Marker3Ds)

    @property
    def thickness(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Thickness() As double
                | 
                |     Returns or sets the thickness of the section.
                | 
                |     The thickness value must be greater than 0.
                | 
                |     Example:
                | 
                |              The first example retrieves the thickness of NewSection
                |              Section.
                |             
                | 
                |             Dim SectionThickness As double
                |             SectionThickness = NewSection.Thickness
                |             
                | 
                | 
                |             
                | 
                |                 The second example sets the thickness value of NewSection
                |                 Section.
                |                 
                | 
                |                 NewSection.Thickness = 100.

        :return: float
        :rtype: float
        """

        return self.section.Thickness

    @thickness.setter
    def thickness(self, value: float):
        """
        :param float value:
        """

        self.section.Thickness = value

    @property
    def type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Type() As CatSectionType
                | 
                |     Returns or sets the type of the section.
                | 
                |     The type value are defined in CatSectionType.
                | 
                |     Example:
                | 
                |              The first example retrieves the type of NewSection
                |              Section.
                |             
                | 
                |             Dim SectionType As CatSectionType
                |             SectionType = NewSection.Type
                |             
                | 
                | 
                |             
                | 
                |                 The second example sets the type of NewSection
                |                 Section.
                |                 
                | 
                |                 NewSection.Type = catSectionTypeSlice

        :return: int
        :rtype: int
        """

        return self.section.Type

    @type.setter
    def type(self, value: int):
        """
        :param int value:
        """

        self.section.Type = value

    @property
    def width(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Width() As double
                | 
                |     Returns or sets the width of the section.
                | 
                |     The width value must be greater than 0.
                | 
                |     Example:
                | 
                |              The first example retrieves the width of NewSection
                |              Section.
                |             
                | 
                |             Dim SectionWidth As double
                |             SectionWidth = NewSection.Width
                |             
                | 
                | 
                |             
                | 
                |                 The second example sets the width value of NewSection
                |                 Section.
                |                 
                | 
                |                 NewSection.Width = 100.

        :return: float
        :rtype: float
        """

        return self.section.Width

    @width.setter
    def width(self, value: float):
        """
        :param float value:
        """

        self.section.Width = value

    def export(self) -> 'Document':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Export() As Document
                | 
                |     Exports the sections curves of the section in a document.
                | 
                |     Returns:
                |         The document 
                |     Example:
                | 
                |              This example exports the section curves of NewSection Section in
                |              PartDoc document.
                |             
                | 
                |             Dim PartDoc As Document
                |             PartDoc = NewSection.Export

        :return: Document
        :rtype: Document
        """
        from pycatia.in_interfaces.document import Document
        return Document(self.section.Export())

    def get_position(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetPosition(CATSafeArrayVariant oComponents)
                | 
                |     Retrieves the position of the section.
                | 
                |     The position of the section is made of a coordinate system whose origin is
                |     the center of the section, and X and Y axes lie on the section. It is retrieved
                |     in an array of the X, Y, Z axes components and the origin components with
                |     respect to the absolute coordinate system.
                | 
                |     Parameters:
                | 
                |         oComponents
                |             The position of the section
                | 
                |                 oComponents( 0) is the X component of the
                |                 X-axis
                |                 oComponents( 1) is the Y component of the
                |                 X-axis
                |                 oComponents( 2) is the Z component of the
                |                 X-axis
                |                 oComponents( 3) is the X component of the
                |                 Y-axis
                |                 oComponents( 4) is the Y component of the
                |                 Y-axis
                |                 oComponents( 5) is the Z component of the
                |                 Y-axis
                |                 oComponents( 6) is the X component of the
                |                 Z-axis
                |                 oComponents( 7) is the Y component of the
                |                 Z-axis
                |                 oComponents( 8) is the Z component of the
                |                 Z-axis
                |                 oComponents( 9) is the X component of the
                |                 origin
                |                 oComponents(10) is the Y component of the
                |                 origin
                |                 oComponents(11) is the Z component of the origin
                |                 
                | 
                |     Example:
                | 
                |              This example retrieves the position of NewSection
                |              Section.
                |             
                | 
                |             Dim Components (11)
                |             NewSection.GetPosition Components

        :return: tuple
        :rtype: tuple
        """

        vba_function_name = 'get_position'
        vba_code = """
        Public Function get_position(section)
            Dim oComponents(11)
            section.GetPosition oComponents
            get_position = oComponents
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def is_empty(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func IsEmpty() As long
                | 
                |     Indicates whether the section is empty.
                | 
                |     The indicator value is 0 if the section is empty or 1 if the section
                |     comprise at least one segment.
                | 
                |     Example:
                | 
                |              This example retrieves the information on NewSection
                |              Section.
                |             
                | 
                |             Dim Indicator
                |             Indicator = NewSection.IsEmpty

        :return: int
        :rtype: int
        """
        return self.section.IsEmpty()

    def set_position(self, i_components: tuple):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetPosition(CATSafeArrayVariant iComponents)
                | 
                |     Sets the position of the section.
                | 
                |     Parameters:
                | 
                |         oComponents
                |             The position of the section with respect to the absolute coordinate
                |             system
                | 
                |                 iComponents( 0) is the X component of the
                |                 X-axis
                |                 iComponents( 1) is the Y component of the
                |                 X-axis
                |                 iComponents( 2) is the Z component of the
                |                 X-axis
                |                 iComponents( 3) is the X component of the
                |                 Y-axis
                |                 iComponents( 4) is the Y component of the
                |                 Y-axis
                |                 iComponents( 5) is the Z component of the
                |                 Y-axis
                |                 iComponents( 6) is the X component of the
                |                 Z-axis
                |                 iComponents( 7) is the Y component of the
                |                 Z-axis
                |                 iComponents( 8) is the Z component of the
                |                 Z-axis
                |                 iComponents( 9) is the X component of the
                |                 origin
                |                 iComponents(10) is the Y component of the
                |                 origin
                |                 iComponents(11) is the Z component of the origin
                |                 
                | 
                |     Example:
                | 
                |              This example sets the position of NewSection
                |              Section.
                |             
                | 
                |             Dim MatrixPos (11) As Double
                |             MatrixPos( 0) = 1.0
                |             MatrixPos( 1) = 0.0
                |             MatrixPos( 2) = 0.0
                |             MatrixPos( 3) = 0.0
                |             MatrixPos( 4) = 1.0
                |             MatrixPos( 5) = 0.0
                |             MatrixPos( 6) = 0.0
                |             MatrixPos( 7) = 0.0
                |             MatrixPos( 8) = 1.0
                |             MatrixPos( 9) = 1000.0
                |             MatrixPos(10) = 0.0
                |             MatrixPos(11) = 0.0
                |             NewSection.SetPosition MatrixPos

        :param tuple i_components:
        """
        return self.section.SetPosition(i_components)

    def __repr__(self):
        return f'Section(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.

"""
from typing import Iterator

from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.constraint import Constraint
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class Constraints(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Constraints
                |
                | A collection of all geometric constraints set on a part, a sketch, or a
                | product.
                | A constraint collection is created with default values for its properties (such
                | as value, orientation, etc.). Use the constraint properties edition services to
                | set them to appropriate values after constraint creation.
                |
                | See also:
                |     Constraint

    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Constraint)
        self.constraints = com_object

    @property
    def broken_constraints_count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property BrokenConstraintsCount() As long (Read Only)
                | 
                |     Returns the number of broken constraints from the Constraints
                |     collection.
                | 
                |     Example:
                |         The following example retrieves in BknCstNum the number of broken
                |         constraints from the myListofConstraints collection of
                |         constraints:
                | 
                |          BknCstNum = myListofConstraints.BrokenConstraintsCount

        :return: int
        :rtype: int
        """

        return self.constraints.BrokenConstraintsCount

    @property
    def un_updated_constraints_count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property UnUpdatedConstraintsCount() As long (Read Only)
                | 
                |     Returns the number of unupdated constraints from the Constraints
                |     collection.
                | 
                |     Example:
                |         The following example retrieves in UnUpdCstNum the number of unupdated
                |         constraints from the myListofConstraints collection of
                |         constraints:
                | 
                |          UnUpdCstNum = myListofConstraints.UnUpdatedConstraintsCount

        :return: int
        :rtype: int
        """

        return self.constraints.UnUpdatedConstraintsCount

    def add_bi_elt_cst(self, i_cst_type: int, i_first_elem: Reference, i_second_elem: Reference) -> Constraint:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func AddBiEltCst(CatConstraintType iCstType,
                | Reference iFirstElem,
                | Reference iSecondElem) As Constraint
                | 
                |     Creates a new constraint applying to two geometric elements and adds it to
                |     the Constraints collection.
                |
                |     Parameters:
                |
                |         iCstType
                |             The constraint type
                |         iFirstElem
                |             The first constrained geometric element
                |             The following
                | 
                |         Boundary object is supported: Boundary.
                |     iSecondElem
                |         The second constrained geometric element
                |         The following Boundary object is supported: Boundary.
                |
                | Example:
                |     This example adds the NewCst tangency constraint in a sketch, between the
                |     two circles c1 and c2 using the value 4 for
                |     catCstTypeTangency.
                |
                |      Set newCst = skCstList.AddBiEltCst(4, c1, c2)

        :param int i_cst_type:
        :param Reference i_first_elem:
        :param Reference i_second_elem:
        :return: Constraint
        :rtype: Constraint
        """
        return Constraint(self.constraints.AddBiEltCst(i_cst_type, i_first_elem.com_object, i_second_elem.com_object))

    def add_mono_elt_cst(self, i_cst_type: int, i_elem: Reference) -> Constraint:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func AddMonoEltCst(CatConstraintType iCstType,
                | Reference iElem) As Constraint
                | 
                |     Creates a new constraint applying to a single geometric element and adds it
                |     to the Constraints collection.
                |
                |     Parameters:
                |
                |         iCstType
                |             The constraint type
                |         iElem
                |             The constrained geometric element
                |             The following
                |
                |         Boundary object is supported: Boundary.
                |
                | Example:
                |     This example creates the reference constraint NewCst to a part, stating
                |     that the P1 point should remain fixed with respect to the part's origin
                |     elements using the value 0 for catCstTypeReference, and adds it to the cstList
                |     collection.
                |
                |      Set NewCst = cstList.AddMonoEltCst(0, P1)

        :param int i_cst_type:
        :param Reference i_elem:
        :return: Constraint
        :rtype: Constraint
        """
        return Constraint(self.constraints.AddMonoEltCst(i_cst_type, i_elem.com_object))

    def add_tri_elt_cst(self, i_cst_type: int, i_first_elem: Reference, i_second_elem: Reference,
                        i_third_elem: Reference) -> Constraint:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func AddTriEltCst(CatConstraintType iCstType,
                | Reference iFirstElem,
                | Reference iSecondElem,
                | Reference iThirdElem) As Constraint
                | 
                |     Creates a new constraint applying to three geometric elements and adds it
                |     to the Constraints collection.
                |
                |     Parameters:
                |
                |         iCstType
                |             The constraint type
                |         iFirstElem
                |             The first constrained geometric element
                |             The following
                | 
                |         Boundary object is supported: Boundary.
                |     iSecondElem
                |         The second constrained geometric element
                |         The following Boundary object is supported: Boundary.
                |     iThirdElem
                |         The third constrained geometric element
                |         The following Boundary object is supported: Boundary.
                | 
                | Example:
                |     This example adds symCst symmetry constraint in a part, stating that the
                |     cylinders cyl1 and cyl2 are symmetric with respect to the plane symPlane using
                |     the value 15 for catCstTypeSymmetry.
                |
                |      Set symCst = prtCstList.AddTriEltCst(15, cyl1, cyl2, symPlane)

        :param int i_cst_type:
        :param Reference i_first_elem:
        :param Reference i_second_elem:
        :param Reference i_third_elem:
        :return: Constraint
        :rtype: Constraint
        """
        return Constraint(self.constraints.AddTriEltCst(i_cst_type, i_first_elem.com_object, i_second_elem.com_object,
                                                        i_third_elem.com_object))

    def item(self, i_index: cat_variant) -> Constraint:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Item(CATVariant iIndex) As Constraint
                | 
                |     Returns a constraint using its index or its name from the Constraints
                |     collection.
                |
                |     Parameters:
                |
                |         iIndex
                |             The index or the name of the constraint to retrieve frm the
                |             collection of constraints. As a numerics, this index is the rank of the
                |             constraint in the collection. The index of the first constraint in the
                |             collection is 1, and the index of the last constraint is Count. As a string, it
                |             is the name you assigned to the constraint using the
                |
                | 
                |         AnyObject.Name property.
                |     Returns:
                |         The retrieved constraint
                |     Example:
                |         This example retrieves in cst1 the first constraint in the collection
                |         and in cst2 the constraint Constraint.2.
                |
                |          Set cst1 = cstList.Item(1)
                |          Set cst2 = cstList.Item("Constraint.2")

        :param cat_variant i_index:
        :return: Constraint
        :rtype: Constraint
        """
        return Constraint(self.constraints.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes a constraint from the Constraints collection.
                |
                |     Parameters:
                |
                |         iIndex
                |             The index or the name of the constraint to remove from the
                |             Constraints collection. As a numerics, this index is the rank of the constraint
                |             in the collection. The index of the first constraint in the collection is 1,
                |             and the index of the last constraint is Count. As a string, it is the name you
                |             assigned to the constraint using the
                |
                |         AnyObject.Name property.
                |
                | Example:
                |     This example removes the last constraint in the
                |     collection.
                | 
                |      cstList.Remove(cstList.Count)

        :param cat_variant i_index:
        :return: None
        :rtype: None
        """
        return self.constraints.Remove(i_index)

    def __getitem__(self, n: int) -> Constraint:
        if (n + 1) > self.count:
            raise StopIteration

        return Constraint(self.constraints.item(n + 1))

    def __iter__(self) -> Iterator[Constraint]:
        for i in range(self.count):
            yield self.child_object(self.com_object.item(i + 1))

    def __repr__(self):
        return f'Constraints(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.relation import Relation


class Law(Relation):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     KnowledgeInterfaces.KnowledgeObject
                |                        KnowledgeInterfaces.KnowledgeActivateObject
                |                             KnowledgeInterfaces.Relation
                |                                 Law
                | 
                | Represents the Law object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.law = com_object

    def add_formal_parameter(self, i_name: str, i_magnitude: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub AddFormalParameter(CATBSTR iName,
                | CATBSTR iMagnitude)
                | 
                |     Creates a formal parameter for the law.
                | 
                |     Parameters:
                | 
                |         iName
                |             The name of the formal parameter. 
                |         iType
                |             The type name of the formal parameter.

        :param str i_name:
        :param str i_magnitude:
        :return: None
        :rtype: None
        """
        return self.law.AddFormalParameter(i_name, i_magnitude)

    def remove_formal_parameter(self, i_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub RemoveFormalParameter(CATBSTR iName)
                | 
                |     Removes a formal parameter of the law.
                | 
                |     Parameters:
                | 
                |         iName
                |             The name of the formal parameter.

        :param str i_name:
        :return: None
        :rtype: None
        """
        return self.law.RemoveFormalParameter(i_name)

    def __repr__(self):
        return f'Law(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.real_param import RealParam
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeDirection(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeDirection
                | 
                | Represents the hybrid shape direction feature object.
                | Role: To access the data of the hybrid shape direction feature object. A
                | direction can be specified using:
                | 
                |     A line: the direction is tangent to the line
                |     A plane: the direction is normal to the plane
                |     Its components
                | 
                | Use the CATIAHybridShapeFactory to create a HybridShapeDirection
                | object.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_direction = com_object

    @property
    def object(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Object() As Reference
                | 
                |     Returns or sets the object that specifies the direction.
                |     This object can be a line or a plane.
                | 
                |     Parameters:
                | 
                |         oObject
                |             The object (a line or a plane) that specifies the
                |             direction
                | 
                |             Sub-element(s) supported (see 
                | 
                |         Boundary object): RectilinearTriDimFeatEdge, RectilinearBiDimFeatEdge
                |         or RectilinearMonoDimFeatEdge.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_direction.Object)

    @object.setter
    def object(self, reference: Reference):
        """
        :param Reference reference:
        """

        self.hybrid_shape_direction.Object = reference.com_object

    @property
    def ref_axis_system(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property RefAxisSystem() As Reference
                | 
                |     Returns or Sets the reference Axis System for Direction
                |     feature.
                |     This data is not mandatory, if element is null, the absolute axis system is
                |     taken.
                |     When an element is given, X, Y and Z are considered in this Axis system.
                |     
                | Example
                | :
                |     This example retrieves in oRefAxis the reference Axis System for Direction
                |     feature.
                | 
                |      Dim oRefAxis As CATIAReference
                |      Set oRefAxis  = Direction.RefAxisSystem

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_direction.RefAxisSystem)

    @ref_axis_system.setter
    def ref_axis_system(self, reference_axis: Reference):
        """
        :param Reference reference_axis:
        """

        self.hybrid_shape_direction.RefAxisSystem = reference_axis.com_object

    @property
    def type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Type() As long (Read Only)
                | 
                |     Returns the direction type.
                |     Legal value: The direction type can be:
                | 
                |     0
                |         The direction is specified using an object (a line or a plane). In the
                |         case of a plane, the direction is the normal to the
                |         plane
                |     1
                |         The direction is specified using its components

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_direction.Type

    def direction_specification(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func DirectionSpecification() As long
                | 
                |     Queries the direction specification status.
                | 
                |     Parameters:
                | 
                |         oDir
                |             direction specification = 0 : Direction is not specified. = 1 :
                |            Direction is specified and is valid. = -1 : Direction is specified but is not valid.

        :return: int
        :rtype: int
        """
        return self.hybrid_shape_direction.DirectionSpecification()

    def get_x(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetX() As RealParam
                | 
                |     Returns the direction X component. This method succeeds only when direction
                |     is specified using components. It fails when direction is specified using a
                |     geometrical element i.e Line, Plane. In such cases use GetXVal method
                |     instead.
                | 
                |     Parameters:
                | 
                |         oCoordinates
                |             The direction X component

        :return: RealParam
        :rtype: RealParam
        """
        return RealParam(self.hybrid_shape_direction.GetX())

    def get_x_val(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetXVal() As double
                | 
                |     Returns the direction X component as Double. This method succeeds
                |     irrespective of the way direction is specified.
                | 
                |     Parameters:
                | 
                |         oX
                |             The direction X component

        :return: float
        :rtype: float
        """
        return self.hybrid_shape_direction.GetXVal()

    def get_y(self) -> RealParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetY() As RealParam
                | 
                |     Returns the direction Y component. This method succeeds only when direction
                |     is specified using components. It fails when direction is specified using a
                |     geometrical element i.e Line, Plane. In such cases use GetYVal method
                |     instead.
                | 
                |     Parameters:
                | 
                |         oCoordinates
                |             The direction Y component

        :return: RealParam
        :rtype: RealParam
        """
        return RealParam(self.hybrid_shape_direction.GetY())

    def get_y_val(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetYVal() As double
                | 
                |     Returns the direction Y component as Double.This method succeeds
                |     irrespective of the way direction is specified.
                | 
                |     Parameters:
                | 
                |         oY
                |             The direction Y component

        :return: float
        :rtype: float
        """
        return self.hybrid_shape_direction.GetYVal()

    def get_z(self) -> RealParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetZ() As RealParam
                | 
                |     Returns the direction Z component. This method succeeds only when direction
                |     is specified using components. It fails when direction is specified using a
                |     geometrical element i.e Line, Plane. In such cases use GetZVal method
                |     instead.
                | 
                |     Parameters:
                | 
                |         oCoordinates
                |             The direction Z component

        :return: RealParam
        :rtype: RealParam
        """
        return RealParam(self.hybrid_shape_direction.GetZ())

    def get_z_val(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetZVal() As double
                | 
                |     Returns the direction Z component as Double.This method succeeds
                |     irrespective of the way direction is specified.
                | 
                |     Parameters:
                | 
                |         oZ
                |             The direction Z component

        :return: float
        :rtype: float
        """
        return self.hybrid_shape_direction.GetZVal()

    def __repr__(self):
        return f'HybridShapeDirection(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.in_interfaces.reference import Reference
from pycatia.part_interfaces.limit import Limit
from pycatia.part_interfaces.sketch_based_shape import SketchBasedShape


class Prism(SketchBasedShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         PartInterfaces.SketchBasedShape
                |                             Prism
                | 
                | Prism-based features in Part Design : base for pad or pocket.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.prism = com_object

    @property
    def direction_orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property DirectionOrientation() As CatPrismOrientation
                | 
                |     Returns the prism direction orientation.
                | 
                |     Returns:
                |         oOrientation The direction orientation (see CatPrismOrientation for
                |         list of possible types)
                | 
                |         Example:
                |             The following example saves in dirOrientation the direction
                |             orientation of prism firstPrism, and then sets it so that the direction will be
                |             now inversed :
                | 
                |              Set dirOrientation = firstPrism.DirectionOrientation
                |              firstPrism.DirectionOrientation = catInverseOrientation

        :return: int
        :rtype: int
        """

        return self.prism.DirectionOrientation

    @direction_orientation.setter
    def direction_orientation(self, value: int):
        """
        :param int value:
        """

        self.prism.DirectionOrientation = value

    @property
    def direction_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property DirectionType() As CatPrismExtrusionDirection
                | 
                |     Returns the prism direction type.
                | 
                |     Returns:
                |         oDirType The direction type (see CatPrismExtrusionDirection for list of
                |         possible types)
                | 
                |         Example:
                |             The following example saves in dirType the direction type of prism
                |             firstPrism, and then sets it so that the direction will be now normal to the
                |             sketch :
                | 
                |              Set dirType = firstPrism.DirectionType
                |              firstPrism.DirectionType = catNormalToSketchDirection

        :return: int
        :rtype: int
        """

        return self.prism.DirectionType

    @direction_type.setter
    def direction_type(self, value: int):
        """
        :param int value:
        """

        self.prism.DirectionType = value

    @property
    def first_limit(self) -> Limit:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstLimit() As Limit (Read Only)
                | 
                |     Returns the first prism limit (one of the two).
                |     This limit manages the way the prism is ended.
                | 
                |     Returns:
                |         oFirstLimit The first limit (see Limit for more
                |         information)
                | 
                |         Example:
                |             The following example returns in firstLimit the first limit of
                |             prism firstPrism:
                | 
                |              Set firstLimit = firstPrism.FirstLimit

        :return: Limit
        :rtype: Limit
        """

        return Limit(self.prism.FirstLimit)

    @property
    def is_symmetric(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property IsSymmetric() As boolean
                | 
                |     Returns the prism symmetry flag.
                |     It returns TRUE if the prism is symmetric (from the base sketch), FALSE if
                |     not.
                | 
                |     Returns:
                |         oIsSymmetric The symmetry flag as a boolean
                | 
                |         Example:
                |             The following example saves in symFlag the symmetry flag of prism
                |             firstPrism, and then sets it so that it will be now symmetric (from the base
                |             sketch) :
                | 
                |              Set symFlag = firstPrism.IsSymmetric
                |              firstPrism.IsSymmetric = TRUE

        :return: bool
        :rtype: bool
        """

        return self.prism.IsSymmetric

    @is_symmetric.setter
    def is_symmetric(self, value: bool):
        """
        :param bool value:
        """

        self.prism.IsSymmetric = value

    @property
    def is_thin(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property IsThin() As boolean
                | 
                |     Returns the prism thin flag.
                |     It returns TRUE if the prism is a thin prism , FALSE if
                |     not.
                | 
                |     Returns:
                |         oIsThin The thin flag as a boolean
                | 
                |         Example:
                |             The following example saves in thinFlag the thin flag of prism
                |             firstPrism, and then sets it so that it will be now thin
                |             :
                | 
                |              Set thinFlag = firstPrism.IsThin
                |              firstPrism.IsThin = TRUE

        :return: bool
        :rtype: bool
        """

        return self.prism.IsThin

    @is_thin.setter
    def is_thin(self, value: bool):
        """
        :param bool value:
        """

        self.prism.IsThin = value

    @property
    def merge_end(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MergeEnd() As boolean
                | 
                |     Returns the prism merge end flag (for thin prism only).
                |     It returns TRUE if merge ends is required , FALSE if not.
                | 
                |     Returns:
                |         oIsMergeEnd The merge end flag as a boolean
                | 
                |         Example:
                |             The following example saves in MergeEndFlag the merge end flag of
                |             prism firstPrism, and then sets it so that merge end will be required
                |             :
                | 
                |              Set MergeEndFlag = firstPrism.IsMergeEnd
                |              firstPrism.IsMergeEnd = TRUE

        :return: bool
        :rtype: bool
        """

        return self.prism.MergeEnd

    @merge_end.setter
    def merge_end(self, value: bool):
        """
        :param bool value:
        """

        self.prism.MergeEnd = value

    @property
    def neutral_fiber(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property NeutralFiber() As boolean
                | 
                |     Returns the prism neutral fiber flag (for thin prism
                |     only).
                |     It returns TRUE if the prism is a neutral fiber prism , FALSE if
                |     not.
                | 
                |     Returns:
                |         oIsNeutralFiber The neutral fiber flag as a boolean
                | 
                |         Example:
                |             The following example saves in NeutralFiberFlag the neutral fiber
                |             flag of prism firstPrism, and then sets it so that it will be now neutral fiber
                |             :
                | 
                |              Set NeutralFiberFlag = firstPrism.IsNeutralFiber
                |              firstPrism.IsNeutralFiber = TRUE

        :return: bool
        :rtype: bool
        """

        return self.prism.NeutralFiber

    @neutral_fiber.setter
    def neutral_fiber(self, value: bool):
        """
        :param bool value:
        """

        self.prism.NeutralFiber = value

    @property
    def second_limit(self) -> Limit:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondLimit() As Limit (Read Only)
                | 
                |     Returns the second prism limit (one of the two).
                |     This limit manages the way the prism is ended.
                | 
                |     Returns:
                |         oSecondLimit The second limit (see Limit for more
                |         information)
                | 
                |         Example:
                |             The following example returns in secondLimit the second limit of
                |             prism firstPrism:
                | 
                |              Set secondLimit = firstPrism.SecondLimit

        :return: Limit
        :rtype: Limit
        """

        return Limit(self.prism.SecondLimit)

    def get_direction(self, io_direction: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetDirection(CATSafeArrayVariant ioDirection)
                | 
                |     Returns the prism direction with absolute coordinates.
                |     It needs a safe array with 3 elements : X, Y, Z direction coordinates
                |     The array must be previously initialized
                | 
                |     Returns:
                |         ioDirection The direction coordinates
                | 
                |         Example:
                |             The following example returns in dirArray the direction coordinates
                |             of prism firstPrism:
                | 
                |              Dim dirArray(2)
                |              Call firstPrism.GetDirection(dirArray)
                |              Set x = dirArray[1]
                |              Set y = dirArray[2]
                |              Set z = dirArray[3]

        :param tuple io_direction:
        :return: None
        :rtype: None
        """
        return self.prism.GetDirection(io_direction)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_direction'
        # # vba_code = """
        # # Public Function get_direction(prism)
        # #     Dim ioDirection (2)
        # #     prism.GetDirection ioDirection
        # #     get_direction = ioDirection
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def reverse_inner_side(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub ReverseInnerSide()
                | 
                |     Reverses the prism inner side when the profile is open. This is useful for
                |     finding the shape to reach.
                | 
                |     Example:
                |         The following example reverses the current inner side of prism
                |         firstPrism :
                | 
                |          firstPrism.ReverseInnerSide

        :return: None
        :rtype: None
        """
        return self.prism.ReverseInnerSide()

    def set_direction(self, i_line: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetDirection(Reference iLine)
                | 
                |     Sets the prism associative direction.
                | 
                |     Parameters:
                | 
                |         iLine
                |             The support direction reference (see 
                | 
                |         Reference for more information)
                |         This reference can be valuated with a reference to a line or an
                |         edge.
                |         The following Boundary objects are supported: PlanarFace,
                |         RectilinearTriDimFeatEdge and
                |         RectilinearBiDimFeatEdge.
                | 
                |         Example:
                |             The following example sets the prism direction reference of prism
                |             firstPrism with prismDirRef line :
                | 
                |              firstPrism.SetDirection prismDirRef

        :param Reference i_line:
        :return: None
        :rtype: None
        """
        return self.prism.SetDirection(i_line.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_direction'
        # # vba_code = """
        # # Public Function set_direction(prism)
        # #     Dim iLine (2)
        # #     prism.SetDirection iLine
        # #     set_direction = iLine
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Prism(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.

"""

from pycatia.mec_mod_interfaces.face import Face


class CylindricalFace(Face):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.Reference
                |                         MecModInterfaces.Boundary
                |                             MecModInterfaces.Face
                |                                 CylindricalFace
                |
                | 2-D boundary with a cylindrical geometry.
                | Role: This Boundary object may be, for example, the lateral face of a
                | cylinder.
                | You will create a CylindricalFace object using the Shapes.GetBoundary ,
                | HybridShapes.GetBoundary , Sketches.GetBoundary or Selection.SelectElement2
                | method. Then, you pass it to the operator (such as
                | ShapeFactory.AddNewCircPattern ).
                | The lifetime of a CylindricalFace object is limited, see
                | Boundary.
                |
                | Example:
                |     This example asks the end user to select a shape to pattern and a
                |     cylindrical face, and creates a circular pattern of the shape. The cylindrical
                |     face specifies the rotation axis.
                |
                |      Dim InputObjectType(0)
                |      Set Document = CATIA.ActiveDocument
                |      Set Selection = Document.Selection
                |      'We propose to the user that he select the shape to
                |      pattern
                |      InputObjectType(0)="SketchBasedShape"
                |      Status=Selection.SelectElement2(InputObjectType,"Select the shape to
                |      pattern",true)
                |      if (Status = "cancel") then Exit Sub
                |      Set Shape = Selection.Item(1).Value
                |      Selection.Clear
                |      'We propose to the user that he select the cylindrical
                |      face
                |      InputObjectType(0)="CylindricalFace"
                |      Status=Selection.SelectElement2(InputObjectType,"Select the cylindrical
                |      face",true)
                |      if (Status = "cancel") then Exit Sub
                |      Set CylindricalFace = Selection.Item(1).Value
                |      Set RotationCenter = Document.Part.CreateReferenceFromName("")
                |      Set CircPattern = ShapeFactory.AddNewCircPattern(Shape,1,4,20.0,45.0,1,4,RotationCenter,
                |                            CylindricalFace,True,0.0,True)
                |      Document.Part.Update

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.cylindrical_face = com_object

    def get_direction(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub GetDirection(CATSafeArrayVariant oDirection)
                | 
                |     Returns the direction of the cylindrical face axis
                |
                |     Parameters:
                |
                |         oDirection[0]
                |             The X Coordinate of the axis direction
                |         oDirection[1]
                |             The Y Coordinate of the axis direction
                |         oDirection[2]
                |             The Z Coordinate of the axis direction

        :param tuple o_direction:
        :return: None
        """

        vba_function_name = 'get_direction'
        vba_code = """
        Public Function get_direction(cylindrical_face)
            Dim oDirection (2)
            cylindrical_face.GetDirection oDirection
            get_direction = oDirection
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_origin(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub GetOrigin(CATSafeArrayVariant oOrigin)
                | 
                |     Returns the origin of the cylindrical face axis.
                |
                |     Parameters:
                |
                |         oOrigin[0]
                |             The X Coordinate of the axis origin
                |         oOrigin[1]
                |             The Y Coordinate of the axis origin
                |         oOrigin[2]
                |             The Z Coordinate of the axis origin

        :param tuple o_origin:
        :return: None
        :rtype: None
        """

        vba_function_name = 'get_origin'
        vba_code = """
        Public Function get_origin(cylindrical_face)
            Dim oOrigin (2)
            cylindrical_face.GetOrigin oOrigin
            get_origin = oOrigin
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'CylindricalFace(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.

"""
from typing import Iterator

from pycatia.mec_mod_interfaces.axis_system import AxisSystem
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class AxisSystems(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     AxisSystems
                | 
                | A collection of all the AxisSystem objects contained in the
                | part.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=AxisSystem)
        self.axis_systems = com_object

    def add(self) -> AxisSystem:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Add() As AxisSystem
                | 
                |     Creates a new AxisSystem and adds it to the AxisSystems
                |     collection.
                | 
                |     Returns:
                |         The created AxisSystem 
                |     Example:
                |         The following example creates a AxisSystem names NewAxisSystem in the
                |         AxisSystem collection of the rootPart part in the partDoc part
                |         document.
                | 
                |          Set rootPart = partDoc.Part
                |          Set NewAxisSystem = rootPart.AxisSystems.Add()

        :return: AxisSystem
        :rtype: AxisSystem
        """
        return AxisSystem(self.axis_systems.Add())

    def item(self, i_index: cat_variant) -> AxisSystem:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Item(CATVariant iIndex) As AxisSystem
                | 
                |     Returns an Axis System using its index or its name from the AxisSystems
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the AxisSystem to retrieve from the
                |             collection of AxisSystems. As a numerics, this index is the rank of the
                |             AxisSystem in the collection. The index of the first AxisSystem in the
                |             collection is 1, and the index of the last AxisSystem is Count. As a string, it
                |             is the name you assigned to the AxisSystem using the
                |             
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved AxisSystem 
                |     Example:
                |         This example retrieves in ThisAxisSystem the fifth AxisSystem in the
                |         collection and in ThatAxisSystem the AxisSystem named MyAxisSystem in the
                |         AxisSystem collection of the partDoc part document.
                | 
                |          Set AxisSystemColl = partDoc.Part.AxisSystems
                |          Set ThisAxisSystem = AxisSystemColl.Item(5)
                |          Set ThatAxisSystem = AxisSystemColl.Item("MyAxisSystem")

        :param cat_variant i_index:
        :return: AxisSystem
        :rtype: AxisSystem
        """
        return AxisSystem(self.axis_systems.Item(i_index))

    def __getitem__(self, n: int) -> AxisSystem:
        if (n + 1) > self.count:
            raise StopIteration

        return AxisSystem(self.axis_systems.item(n + 1))

    def __iter__(self) -> Iterator[AxisSystem]:
        for i in range(self.count):
            yield self.child_object(self.com_object.item(i + 1))

    def __repr__(self):
        return f'AxisSystems(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-09 09:53:18.676780

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class SystemService(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SystemService
                | 
                | Represents an object which provides system services.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.system_service = com_object

    def environ(self, i_env_string):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func Environ(CATBSTR iEnvString) As CATBSTR
                | 
                |     Returns the value of an environment variable.
                | 
                |     Parameters:
                | 
                |         iEnvString
                |             The name of the environment variable 
                | 
                |     Example:
                |         This example retrieves the value of the PATH variable in the Value
                |         string.
                | 
                |          Value = CATIA.SystemService.Environ("PATH")

        :param str i_env_string:
        :return: str
        """
        return str(self.system_service.Environ(i_env_string))

    def evaluate(self, i_script_text, i_language, i_function_name, i_parameters):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func Evaluate(CATBSTR iScriptText,
                | CATScriptLanguage iLanguage,
                | CATBSTR iFunctionName,
                | CATSafeArrayVariant iParameters) As CATVariant
                | 
                |     Evaluates a scripted function.
                | 
                |     Parameters:
                | 
                |         iScriptText
                |             The program text 
                |         iLanguage
                |             The language the program is written in 
                |         iFunctionName
                |             The name of the function to invoke 
                |         iParameters
                |             An array of parameters for the function 
                |         oResult
                |             The value returned by the function (if any) 
                | 
                |     Example:
                |         This example executes the function CATMain from the CodeToEvaluate
                |         string
                | 
                |          Dim params()
                |          Dim codeToEvaluate
                |          CodeToEvaluate = "Sub CATMain()" & vbNewLine & _
                |                           "MsgBox " & chr(34) & "Hello World" & chr(34) &
                |                           vbNewLine & _
                |                           "End Sub"
                |          CATIA.SystemService.Evaluate CodeToEvaluate, CATVBScriptLanguage,
                |          "CATMain", params

        :param str i_script_text:
        :param CATScriptLanguage i_language:
        :param str i_function_name:
        :param list i_parameters:
        :return: None
        """
        return self.system_service.Evaluate(i_script_text, i_language, i_function_name, i_parameters)

    def execute_background_processus(self, i_executable_path):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func ExecuteBackgroundProcessus(CATBSTR iExecutablePath) As
                | long
                | 
                |     Executes an asynchronous process. This process is launched in background
                |     and ExecuteBackgroundProcess doesn't wait for it to complete. If the executable
                |     to run needs a specific environment to works correctly (for example environment
                |     variables like PATH or LD_LIBRARY_PATH correctly set), this environment must
                |     have been set in order to make this method succeed. If this executable needs to
                |     be launched from a window, this method will fail.
                | 
                |     Parameters:
                | 
                |         iExecutablePath
                |             The path of the executable to run and its arguments If the executable is not present in
                |             the PATH environment variable, you must specify its complete absolute path. If this path
                |             contains blanks, you must enclose it with the simple quote character ''' : for example
                |             CATIA.SystemService.ExecuteBackgroundProcess "'C:/Program Files/myApp/myApp.exe' myArg".
                | 
                |     Returns:
                |         Non significative return code. It's never the asynchronous process
                |         return code 
                | 
                | Example:
                |     This example executes the command located at
                | 
                |     and doesn't wait the end of its execution.
                | 
                |      CATIA.SystemService.ExecuteBackgroundProcessus ""

        :param str i_executable_path:
        :return: int
        """
        return int(self.system_service.ExecuteBackgroundProcessus(i_executable_path))

    def execute_processus(self, i_executable_path):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func ExecuteProcessus(CATBSTR iExecutablePath) As long
                | 
                |     Executes a synchronous process. If this process is succesfully launched,
                |     ExecuteProcessus waits for it to terminate and returns the process return code.
                |     If the executable to run needs a specific environment to works correctly (for
                |     example environment variables like PATH or LD_LIBRARY_PATH correctly set), this
                |     environment must have been set in order to make this method succeed. If this
                |     executable needs to be launched from a window, this method will
                |     fail.
                | 
                |     Parameters:
                | 
                |         iExecutablePath
                |             The path of the executable to run and its arguments. If the executable is not present in
                |             the PATH environment variable, you must specify its complete absolute path. If this
                |             executable path contains blanks, you must enclose it with the simple quote
                |             character ''' to allow the implementation to follow the whole line to the MS call
                |             (otherwise only the last part will be sent to the MS call) : Additionally, arguments
                |             with blank must be enclosed in double quote in Microsoft call (do not forget to espace
                |             double quote in VBA, with another double quote).
                |             for example CATIA.SystemService.ExecuteProcessus("'""C:/Program Files/myApp/myApp.exe""'
                |                  myArg1 '""myAr g2""'")
                |             will start the command line "C:/Program Files/myApp/myApp.exe" myArg1 "myAr g2"
                |             on Microsoft OS. On Windows, to run a batch file you must execute the command interpreter
                |             : set the executable to cmd.exe set the arguments to the following ones
                |             : /c plus the name of the batch file. For example CATIA.SystemService.ExecuteProcessus
                |             "cmd.exe /c E:/MyBatchFile.bat" On Windows, an argument that contains a blank must be
                |             doubly enclosed ; first with the single quote character then, inside the single enclosing
                |             quote, with the double quote character. For example CATIA.SystemService.ExecuteProcessus
                |             "cmd.exe /c '" & Chr$(34) & "E:/My Bat File.bat" & Chr$(34) & "'"
                | 
                |     Returns:
                |         The synchronous process return code 
                | 
                | Example:
                |     This example executes the command located at
                | 
                |     waits for it to end, and returns its return code.
                | 
                |      ReturnCode = CATIA.SystemService.ExecuteProcessus("")

        :param str i_executable_path:
        :return: int
        """
        return int(self.system_service.ExecuteProcessus(i_executable_path))

    def execute_script(self, i_library_name, i_type, i_program_name, i_function_name, i_parameters):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func ExecuteScript(CATBSTR iLibraryName,
                | CatScriptLibraryType iType,
                | CATBSTR iProgramName,
                | CATBSTR iFunctionName,
                | CATSafeArrayVariant iParameters) As CATVariant
                | 
                |     Executes a scripted function.
                | 
                |     Parameters:
                | 
                |         iLibraryName
                |             The library in which the script is contained 
                |         iLibraryType
                |             The type of the library 
                |         iProgramName
                |             The name of the program in the library 
                |         iFunctionName
                |             The name of the function to invoke 
                |         iParameters
                |             An array of parameters for the function 
                |         oResult
                |             The value returned by the function (if any) 
                | 
                |     Example:
                |         This example executes the function CATMain in the program Macro1.catvbs
                |         contained by Part1.CATPart
                | 
                |          Dim params()
                |          CATIA.SystemService.ExecuteScript"Part1.CATPart",
                |          catScriptLibraryTypeDocument, "Macro1.catvbs", "CATMain",
                |          params

        :param str i_library_name:
        :param CatScriptLibraryType i_type:
        :param str i_program_name:
        :param str i_function_name:
        :param tuple i_parameters:
        :return: None
        """
        return self.system_service.ExecuteScript(i_library_name, i_type, i_program_name, i_function_name, i_parameters)

    def print(self, i_string):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub Print(CATBSTR iString)
                | 
                |     Prints a string on stdout.
                | 
                |     Parameters:
                | 
                |         iString
                |             The string to print 
                | 
                |     Example:
                |         This example prints the string "Hello world!".
                | 
                |          CATIA.SystemService.Print("Hello world!")

        :param str i_string:
        :return: None
        """
        return self.system_service.Print(i_string)

    def __repr__(self):
        return f'SystemService(name="{self.name}")'
